﻿using System;
using System.Drawing;

public static class ColorHelper {

    /// <summary>
    /// ランダムの HEX カラーを取得します
    /// </summary>
    /// <returns>ランダムの HEX カラー</returns>
    public static string GetRandomColor() {
        var random = new Random();
        int r = random.Next(50, 255);
        int g = random.Next(50, 255);
        int b = random.Next(50, 255);

        return ColorTranslator.ToHtml(Color.FromArgb(r, g, b));
    }

    /// <summary>
    /// HTML の HEX カラーが暗すぎないかどうかを確認します
    /// </summary>
    /// <param name="htmlColor">確認する HEX カラー</param>
    /// <returns>色が十分に明るい場合は True、それ以外の場合は False を返します</returns>
    public static bool IsValidColor(string htmlColor) {
        // 十分な明るさとは、色が有効で
        // その r+g+b が 150 より大きいことを意味します

        try {
            Color c = ColorTranslator.FromHtml(htmlColor);
            return ((c.R + c.G + c.B) >= 150);
        } catch {
            return false;
        }
    }

    /// <summary>
    /// 罫線に使用するために、より暗い色を返します
    /// </summary>
    /// <param name="hex">より暗くする色</param>
    /// <returns>渡された色よりも暗い HEX カラー</returns>
    public static string GetBorderFromHtml(string hex) {

        // これが無効な 16 進数に対して例外をスローするようにしたい
        // のですが、開発者側からのみ使用される必要があるため、
        // それは安全である必要があります。

        Color color = ColorTranslator.FromHtml(hex);

        // HSV または HSL に変換してからより低い V/L に変換する必要があります
        // これらのメソッドは .net にありません。代わりに、R、G、および B の各値を
        // 低くしています。

        int newR = (int)(color.R * .5);
        int newG = (int)(color.G * .5);
        int newB = (int)(color.B * .5);

        Color darker = Color.FromArgb(newR, newG, newB);
        return ColorTranslator.ToHtml(darker);
    }
}