﻿using System.Collections.Generic;
using System.Web;

/// <summary>
/// 他の値と相反する可能性が非常に低い
/// コンテキスト内の情報を格納するヘルパー クラス
/// 
/// このヘルパーに格納されているデータは、要求全体にのみ
/// 存在します。
/// </summary>
public static class RequestData {
    // コンテキスト内で模造の名前空間として使用するキー
    private static readonly object _key = new object();

    /// <summary>
    /// 名前空間に格納されている情報のコレクション全体
    /// を取得します
    /// </summary>
    /// <returns>設定の辞書</returns>
    private static IDictionary<string, object> GetSettings() {
        return GetSettings(new HttpContextWrapper(HttpContext.Current));
    }

    internal static IDictionary<string, object> GetSettings(HttpContextBase context) {
        var settings = context.Items[_key] as IDictionary<string, object>;

        if (settings == null) {
            // それを作成します
            settings = new Dictionary<string, object>();
            context.Items[_key] = settings;
        }

        return settings;
    }

    // コンテキスト内に格納されている項目の汎用オブジェクトを取得します
    public static object GetValue(string key) {
        return GetValue<object>(new HttpContextWrapper(HttpContext.Current), key);
    }

    public static TValue GetValue<TValue>(string key) {
        return GetValue<TValue>(new HttpContextWrapper(HttpContext.Current), key);
    }

    internal static TValue GetValue<TValue>(HttpContextBase context, string key) {
        var settings = GetSettings(context);
        object value;

        if (settings.TryGetValue(key, out value)) {
            return (TValue)value;
        }

        return default(TValue);
    }

    public static void SetValue(string key, object value) {
        SetValue(new HttpContextWrapper(HttpContext.Current), key, value);
    }

    internal static void SetValue(HttpContextBase context, string key, object value) {
        var settings = GetSettings(context);
        settings[key] = value;
    }
}