﻿using System;

/*
このクラスの目標は、Web 開発者向けに簡単なインターフェイスを提供して、
サーバーとは異なる可能性のある、ユーザー固有のタイムゾーンを
使用する Web アプリケーションを作成できるようにすることです。サーバーは UTC を
使用していない可能性があります。
*/
public static class Time {

    // ユーザーのタイムゾーン
    public static string LocalTimeZoneId {
        get {
            var timeZone = RequestData.GetValue<string>("LocalTimeZone");
            if (timeZone == null) {
                throw new InvalidOperationException("要求のローカル タイム ゾーンが設定されていません");
            }

            return timeZone;
        }
        set {
            // 無効な ID が渡さると、InvalidOperationException がスローされます
            RequestData.SetValue("LocalTimeZone", value);
        }
    }

    public static DateTime NowInLocal {
        get {
            return UtcToLocal(DateTime.UtcNow);
        }
    }

    public static DateTime LocalToUtc(DateTime localTime) {
        return TimeZoneInfo.ConvertTimeToUtc(localTime, TimeZoneInfo.FindSystemTimeZoneById(LocalTimeZoneId));
    }

    public static DateTime UtcToLocal(DateTime utcTime) {
        return TimeZoneInfo.ConvertTimeFromUtc(utcTime, TimeZoneInfo.FindSystemTimeZoneById(LocalTimeZoneId));
    }
}